@@ -1,3 +1,5 @@
+import django
+
 from easy_tenants.utils import (
     get_current_tenant,
     get_tenant_model,
@@ -12,4 +14,5 @@ __all__ = [
     "tenant_context_disabled",
 ]
 
-default_app_config = "easy_tenants.apps.EasyTenantsConfig"
+if django.VERSION < (3, 2):
+    default_app_config = "easy_tenants.apps.EasyTenantsConfig"
